# ///////////////////////////////////////////////////////////////
# SHARED.RESOURCES.ICONS - Icons registry
# Project: ezqt_app
# ///////////////////////////////////////////////////////////////

"""
Shared icon resource registry.
"""

from __future__ import annotations

# ///////////////////////////////////////////////////////////////
# CLASSES
# ///////////////////////////////////////////////////////////////


class Icons:
    """
    Application icon management class.

    This class contains paths to all icons
    used in the application, organized by category.
    """

    # ////// CORE ICONS
    icon_close: str = ":/icons/icons/icon_close.png"
    icon_maximize: str = ":/icons/icons/icon_maximize.png"
    icon_menu: str = ":/icons/icons/icon_menu.png"
    icon_minimize: str = ":/icons/icons/icon_minimize.png"
    icon_restore: str = ":/icons/icons/icon_restore.png"
    icon_settings: str = ":/icons/icons/icon_settings.png"

    # ////// MATERIAL ICONS
    material_circled_C: str = ":/icons/icons/material-circled-C.png"
    material_circled_K: str = ":/icons/icons/material-circled-K.png"
    material_copy_24: str = ":/icons/icons/material-copy-24.png"
    material_electricity: str = ":/icons/icons/material-electricity.png"
    material_play_blue: str = ":/icons/icons/material-play-blue.png"
    material_stop_red: str = ":/icons/icons/material-stop-red.png"

    # ////// CIL ICONS - ARROWS
    cil_arrow_bottom_2: str = ":/icons/icons/cil-arrow-bottom-2.png"
    cil_arrow_bottom: str = ":/icons/icons/cil-arrow-bottom.png"
    cil_arrow_circle_bottom: str = ":/icons/icons/cil-arrow-circle-bottom.png"
    cil_arrow_circle_left: str = ":/icons/icons/cil-arrow-circle-left.png"
    cil_arrow_circle_right: str = ":/icons/icons/cil-arrow-circle-right.png"
    cil_arrow_circle_top: str = ":/icons/icons/cil-arrow-circle-top.png"
    cil_arrow_left: str = ":/icons/icons/cil-arrow-left.png"
    cil_arrow_right: str = ":/icons/icons/cil-arrow-right.png"
    cil_arrow_top: str = ":/icons/icons/cil-arrow-top.png"

    # ////// CIL ICONS - NAVIGATION
    cil_chevron_bottom: str = ":/icons/icons/cil-chevron-bottom.png"
    cil_chevron_circle_down_alt: str = ":/icons/icons/cil-chevron-circle-down-alt.png"
    cil_chevron_circle_left_alt: str = ":/icons/icons/cil-chevron-circle-left-alt.png"
    cil_chevron_circle_right_alt: str = ":/icons/icons/cil-chevron-circle-right-alt.png"
    cil_chevron_circle_up_alt: str = ":/icons/icons/cil-chevron-circle-up-alt.png"
    cil_chevron_double_down: str = ":/icons/icons/cil-chevron-double-down.png"
    cil_chevron_double_left: str = ":/icons/icons/cil-chevron-double-left.png"
    cil_chevron_double_right: str = ":/icons/icons/cil-chevron-double-right.png"
    cil_chevron_double_up_alt: str = ":/icons/icons/cil-chevron-double-up-alt.png"
    cil_chevron_double_up: str = ":/icons/icons/cil-chevron-double-up.png"
    cil_chevron_left: str = ":/icons/icons/cil-chevron-left.png"
    cil_chevron_right: str = ":/icons/icons/cil-chevron-right.png"
    cil_chevron_top: str = ":/icons/icons/cil-chevron-top.png"

    # ////// CIL ICONS - ACTIONS
    cil_action_redo: str = ":/icons/icons/cil-action-redo.png"
    cil_action_undo: str = ":/icons/icons/cil-action-undo.png"
    cil_check_alt: str = ":/icons/icons/cil-check-alt.png"
    cil_check_circle: str = ":/icons/icons/cil-check-circle.png"
    cil_check: str = ":/icons/icons/cil-check.png"
    cil_minus: str = ":/icons/icons/cil-minus.png"
    cil_plus: str = ":/icons/icons/cil-plus.png"
    cil_x_circle: str = ":/icons/icons/cil-x-circle.png"
    cil_x: str = ":/icons/icons/cil-x.png"

    # ////// CIL ICONS - ALIGNMENT
    cil_align_center: str = ":/icons/icons/cil-align-center.png"
    cil_align_left: str = ":/icons/icons/cil-align-left.png"
    cil_align_right: str = ":/icons/icons/cil-align-right.png"
    cil_justify_center: str = ":/icons/icons/cil-justify-center.png"
    cil_justify_left: str = ":/icons/icons/cil-justify-left.png"
    cil_justify_right: str = ":/icons/icons/cil-justify-right.png"

    # ////// CIL ICONS - COMMUNICATION
    cil_at: str = ":/icons/icons/cil-at.png"
    cil_chat_bubble: str = ":/icons/icons/cil-chat-bubble.png"
    cil_comment_bubble: str = ":/icons/icons/cil-comment-bubble.png"
    cil_comment_square: str = ":/icons/icons/cil-comment-square.png"
    cil_envelope_closed: str = ":/icons/icons/cil-envelope-closed.png"
    cil_envelope_letter: str = ":/icons/icons/cil-envelope-letter.png"
    cil_envelope_open: str = ":/icons/icons/cil-envelope-open.png"
    cil_phone: str = ":/icons/icons/cil-phone.png"
    cil_speech: str = ":/icons/icons/cil-speech.png"

    # ////// CIL ICONS - DEVICES
    cil_airplane_mode_off: str = ":/icons/icons/cil-airplane-mode-off.png"
    cil_airplane_mode: str = ":/icons/icons/cil-airplane-mode.png"
    cil_battery_0: str = ":/icons/icons/cil-battery-0.png"
    cil_battery_3: str = ":/icons/icons/cil-battery-3.png"
    cil_battery_5: str = ":/icons/icons/cil-battery-5.png"
    cil_battery_alert: str = ":/icons/icons/cil-battery-alert.png"
    cil_battery_slash: str = ":/icons/icons/cil-battery-slash.png"
    cil_bluetooth: str = ":/icons/icons/cil-bluetooth.png"
    cil_devices: str = ":/icons/icons/cil-devices.png"
    cil_ethernet: str = ":/icons/icons/cil-ethernet.png"
    cil_keyboard: str = ":/icons/icons/cil-keyboard.png"
    cil_laptop: str = ":/icons/icons/cil-laptop.png"
    cil_mobile_landscape: str = ":/icons/icons/cil-mobile-landscape.png"
    cil_mobile: str = ":/icons/icons/cil-mobile.png"
    cil_mouse: str = ":/icons/icons/cil-mouse.png"
    cil_screen_desktop: str = ":/icons/icons/cil-screen-desktop.png"
    cil_screen_smartphone: str = ":/icons/icons/cil-screen-smartphone.png"
    cil_wifi_signal_0: str = ":/icons/icons/cil-wifi-signal-0.png"
    cil_wifi_signal_1: str = ":/icons/icons/cil-wifi-signal-1.png"
    cil_wifi_signal_2: str = ":/icons/icons/cil-wifi-signal-2.png"
    cil_wifi_signal_4: str = ":/icons/icons/cil-wifi-signal-4.png"
    cil_wifi_signal_off: str = ":/icons/icons/cil-wifi-signal-off.png"

    # ////// CIL ICONS - MEDIA
    cil_3d: str = ":/icons/icons/cil-3d.png"
    cil_4k: str = ":/icons/icons/cil-4k.png"
    cil_camera_roll: str = ":/icons/icons/cil-camera-roll.png"
    cil_camera: str = ":/icons/icons/cil-camera.png"
    cil_cast: str = ":/icons/icons/cil-cast.png"
    cil_closed_captioning: str = ":/icons/icons/cil-closed-captioning.png"
    cil_hd: str = ":/icons/icons/cil-hd.png"
    cil_hdr: str = ":/icons/icons/cil-hdr.png"
    cil_headphones: str = ":/icons/icons/cil-headphones.png"
    cil_image_plus: str = ":/icons/icons/cil-image-plus.png"
    cil_image1: str = ":/icons/icons/cil-image1.png"
    cil_media_eject: str = ":/icons/icons/cil-media-eject.png"
    cil_media_pause: str = ":/icons/icons/cil-media-pause.png"
    cil_media_play: str = ":/icons/icons/cil-media-play.png"
    cil_media_skip_backward: str = ":/icons/icons/cil-media-skip-backward.png"
    cil_media_skip_forward: str = ":/icons/icons/cil-media-skip-forward.png"
    cil_media_step_backward: str = ":/icons/icons/cil-media-step-backward.png"
    cil_media_step_forward: str = ":/icons/icons/cil-media-step-forward.png"
    cil_media_stop: str = ":/icons/icons/cil-media-stop.png"
    cil_movie: str = ":/icons/icons/cil-movie.png"
    cil_speaker: str = ":/icons/icons/cil-speaker.png"
    cil_volume_high: str = ":/icons/icons/cil-volume-high.png"
    cil_volume_low: str = ":/icons/icons/cil-volume-low.png"
    cil_volume_off: str = ":/icons/icons/cil-volume-off.png"

    # ////// CIL ICONS - INTERFACE
    cil_alarm: str = ":/icons/icons/cil-alarm.png"
    cil_ban: str = ":/icons/icons/cil-ban.png"
    cil_bell: str = ":/icons/icons/cil-bell.png"
    cil_briefcase: str = ":/icons/icons/cil-briefcase.png"
    cil_browser: str = ":/icons/icons/cil-browser.png"
    cil_calendar_check: str = ":/icons/icons/cil-calendar-check.png"
    cil_clock: str = ":/icons/icons/cil-clock.png"
    cil_cursor_move: str = ":/icons/icons/cil-cursor-move.png"
    cil_cursor: str = ":/icons/icons/cil-cursor.png"
    cil_dialpad: str = ":/icons/icons/cil-dialpad.png"
    cil_exit_to_app: str = ":/icons/icons/cil-exit-to-app.png"
    cil_file: str = ":/icons/icons/cil-file.png"
    cil_folder_open: str = ":/icons/icons/cil-folder-open.png"
    cil_folder: str = ":/icons/icons/cil-folder.png"
    cil_home: str = ":/icons/icons/cil-home.png"
    cil_house: str = ":/icons/icons/cil-house.png"
    cil_menu: str = ":/icons/icons/cil-menu.png"
    cil_notes: str = ":/icons/icons/cil-notes.png"
    cil_options_horizontal: str = ":/icons/icons/cil-options-horizontal.png"
    cil_options: str = ":/icons/icons/cil-options.png"
    cil_settings: str = ":/icons/icons/cil-settings.png"
    cil_size_grip: str = ":/icons/icons/cil-size-grip.png"
    cil_task: str = ":/icons/icons/cil-task.png"
    cil_terminal: str = ":/icons/icons/cil-terminal.png"
    cil_window_maximize: str = ":/icons/icons/cil-window-maximize.png"
    cil_window_minimize: str = ":/icons/icons/cil-window-minimize.png"
    cil_window_restore: str = ":/icons/icons/cil-window-restore.png"

    # ////// CIL ICONS - USERS
    cil_account_logout: str = ":/icons/icons/cil-account-logout.png"
    cil_people: str = ":/icons/icons/cil-people.png"
    cil_user_female: str = ":/icons/icons/cil-user-female.png"
    cil_user_follow: str = ":/icons/icons/cil-user-follow.png"
    cil_user_unfollow: str = ":/icons/icons/cil-user-unfollow.png"
    cil_user: str = ":/icons/icons/cil-user.png"

    # ////// CIL ICONS - EMOTIONS
    cil_face_dead: str = ":/icons/icons/cil-face-dead.png"
    cil_frown: str = ":/icons/icons/cil-frown.png"
    cil_meh: str = ":/icons/icons/cil-meh.png"
    cil_mood_bad: str = ":/icons/icons/cil-mood-bad.png"
    cil_mood_good: str = ":/icons/icons/cil-mood-good.png"
    cil_mood_very_bad: str = ":/icons/icons/cil-mood-very-bad.png"
    cil_mood_very_good: str = ":/icons/icons/cil-mood-very-good.png"
    cil_smile: str = ":/icons/icons/cil-smile.png"

    # ////// CIL ICONS - MISC
    cil_av_timer: str = ":/icons/icons/cil-av-timer.png"
    cil_caret_bottom: str = ":/icons/icons/cil-caret-bottom.png"
    cil_caret_left: str = ":/icons/icons/cil-caret-left.png"
    cil_caret_right: str = ":/icons/icons/cil-caret-right.png"
    cil_caret_top: str = ":/icons/icons/cil-caret-top.png"
    cil_cart: str = ":/icons/icons/cil-cart.png"
    cil_chart_line: str = ":/icons/icons/cil-chart-line.png"
    cil_chart_pie: str = ":/icons/icons/cil-chart-pie.png"
    cil_chart: str = ":/icons/icons/cil-chart.png"
    cil_circle: str = ":/icons/icons/cil-circle.png"
    cil_clipboard: str = ":/icons/icons/cil-clipboard.png"
    cil_clone: str = ":/icons/icons/cil-clone.png"
    cil_cloud_download: str = ":/icons/icons/cil-cloud-download.png"
    cil_cloud_upload: str = ":/icons/icons/cil-cloud-upload.png"
    cil_cloudy: str = ":/icons/icons/cil-cloudy.png"
    cil_code: str = ":/icons/icons/cil-code.png"
    cil_coffee: str = ":/icons/icons/cil-coffee.png"
    cil_credit_card: str = ":/icons/icons/cil-credit-card.png"
    cil_cut: str = ":/icons/icons/cil-cut.png"
    cil_data_transfer_down: str = ":/icons/icons/cil-data-transfer-down.png"
    cil_data_transfer_up: str = ":/icons/icons/cil-data-transfer-up.png"
    cil_deaf: str = ":/icons/icons/cil-deaf.png"
    cil_description: str = ":/icons/icons/cil-description.png"
    cil_dog: str = ":/icons/icons/cil-dog.png"
    cil_door: str = ":/icons/icons/cil-door.png"
    cil_double_quote_sans_left: str = ":/icons/icons/cil-double-quote-sans-left.png"
    cil_double_quote_sans_right: str = ":/icons/icons/cil-double-quote-sans-right.png"
    cil_drop: str = ":/icons/icons/cil-drop.png"
    cil_equalizer: str = ":/icons/icons/cil-equalizer.png"
    cil_expand_down: str = ":/icons/icons/cil-expand-down.png"
    cil_expand_left: str = ":/icons/icons/cil-expand-left.png"
    cil_expand_right: str = ":/icons/icons/cil-expand-right.png"
    cil_expand_up: str = ":/icons/icons/cil-expand-up.png"
    cil_exposure: str = ":/icons/icons/cil-exposure.png"
    cil_external_link: str = ":/icons/icons/cil-external-link.png"
    cil_featured_playlist: str = ":/icons/icons/cil-featured-playlist.png"
    cil_find_in_page: str = ":/icons/icons/cil-find-in-page.png"
    cil_fingerprint: str = ":/icons/icons/cil-fingerprint.png"
    cil_fire: str = ":/icons/icons/cil-fire.png"
    cil_flip_to_back: str = ":/icons/icons/cil-flip-to-back.png"
    cil_gamepad: str = ":/icons/icons/cil-gamepad.png"
    cil_hand_point_down: str = ":/icons/icons/cil-hand-point-down.png"
    cil_hand_point_left: str = ":/icons/icons/cil-hand-point-left.png"
    cil_hand_point_right: str = ":/icons/icons/cil-hand-point-right.png"
    cil_hand_point_up: str = ":/icons/icons/cil-hand-point-up.png"
    cil_heart: str = ":/icons/icons/cil-heart.png"
    cil_highligt: str = ":/icons/icons/cil-highligt.png"
    cil_history: str = ":/icons/icons/cil-history.png"
    cil_infinity: str = ":/icons/icons/cil-infinity.png"
    cil_input_power: str = ":/icons/icons/cil-input-power.png"
    cil_input: str = ":/icons/icons/cil-input.png"
    cil_layers: str = ":/icons/icons/cil-layers.png"
    cil_level_down: str = ":/icons/icons/cil-level-down.png"
    cil_level_up: str = ":/icons/icons/cil-level-up.png"
    cil_library_add: str = ":/icons/icons/cil-library-add.png"
    cil_library: str = ":/icons/icons/cil-library.png"
    cil_lightbulb: str = ":/icons/icons/cil-lightbulb.png"
    cil_link_alt: str = ":/icons/icons/cil-link-alt.png"
    cil_link_broken: str = ":/icons/icons/cil-link-broken.png"
    cil_link: str = ":/icons/icons/cil-link.png"
    cil_location_pin: str = ":/icons/icons/cil-location-pin.png"
    cil_lock_locked: str = ":/icons/icons/cil-lock-locked.png"
    cil_lock_unlocked: str = ":/icons/icons/cil-lock-unlocked.png"
    cil_loop_1: str = ":/icons/icons/cil-loop-1.png"
    cil_loop_circular: str = ":/icons/icons/cil-loop-circular.png"
    cil_loop: str = ":/icons/icons/cil-loop.png"
    cil_low_vision: str = ":/icons/icons/cil-low-vision.png"
    cil_magnifying_glass: str = ":/icons/icons/cil-magnifying-glass.png"
    cil_map: str = ":/icons/icons/cil-map.png"
    cil_microphone: str = ":/icons/icons/cil-microphone.png"
    cil_move: str = ":/icons/icons/cil-move.png"
    cil_mug_tea: str = ":/icons/icons/cil-mug-tea.png"
    cil_mug: str = ":/icons/icons/cil-mug.png"
    cil_paint_bucket: str = ":/icons/icons/cil-paint-bucket.png"
    cil_paper_plane: str = ":/icons/icons/cil-paper-plane.png"
    cil_paperclip: str = ":/icons/icons/cil-paperclip.png"
    cil_paragraph: str = ":/icons/icons/cil-paragraph.png"
    cil_pen_alt: str = ":/icons/icons/cil-pen-alt.png"
    cil_pencil: str = ":/icons/icons/cil-pencil.png"
    cil_pin: str = ":/icons/icons/cil-pin.png"
    cil_power_standby: str = ":/icons/icons/cil-power-standby.png"
    cil_print: str = ":/icons/icons/cil-print.png"
    cil_rectangle: str = ":/icons/icons/cil-rectangle.png"
    cil_reload: str = ":/icons/icons/cil-reload.png"
    cil_remove: str = ":/icons/icons/cil-remove.png"
    cil_rss: str = ":/icons/icons/cil-rss.png"
    cil_satelite: str = ":/icons/icons/cil-satelite.png"
    cil_save: str = ":/icons/icons/cil-save.png"
    cil_share_boxed: str = ":/icons/icons/cil-share-boxed.png"
    cil_share: str = ":/icons/icons/cil-share.png"
    cil_signal_cellular_0: str = ":/icons/icons/cil-signal-cellular-0.png"
    cil_signal_cellular_3: str = ":/icons/icons/cil-signal-cellular-3.png"
    cil_speedometer: str = ":/icons/icons/cil-speedometer.png"
    cil_star: str = ":/icons/icons/cil-star.png"
    cil_tags: str = ":/icons/icons/cil-tags.png"
    cil_text_size: str = ":/icons/icons/cil-text-size.png"
    cil_text_square: str = ":/icons/icons/cil-text-square.png"
    cil_text: str = ":/icons/icons/cil-text.png"
    cil_thumb_down: str = ":/icons/icons/cil-thumb-down.png"
    cil_thumb_up: str = ":/icons/icons/cil-thumb-up.png"
    cil_transfer: str = ":/icons/icons/cil-transfer.png"
    cil_trash: str = ":/icons/icons/cil-trash.png"
    cil_triangle: str = ":/icons/icons/cil-triangle.png"
    cil_truck: str = ":/icons/icons/cil-truck.png"
    cil_vertical_align_bottom: str = ":/icons/icons/cil-vertical-align-bottom.png"
    cil_view_column: str = ":/icons/icons/cil-view-column.png"
    cil_view_module: str = ":/icons/icons/cil-view-module.png"
    cil_view_quilt: str = ":/icons/icons/cil-view-quilt.png"
    cil_view_stream: str = ":/icons/icons/cil-view-stream.png"
    cil_voice_over_record: str = ":/icons/icons/cil-voice-over-record.png"
    cil_wallet: str = ":/icons/icons/cil-wallet.png"
    cil_watch: str = ":/icons/icons/cil-watch.png"
    cil_wrap_text: str = ":/icons/icons/cil-wrap-text.png"
    cil_zoom_in: str = ":/icons/icons/cil-zoom-in.png"
    cil_zoom_out: str = ":/icons/icons/cil-zoom-out.png"
